/* ============================================================
* QupZilla - WebKit based browser
* Copyright (C) 2013-2014  David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#ifndef SPELLCHECKDIALOG_H
#define SPELLCHECKDIALOG_H

#include <QDialog>

#include "qzcommon.h"

namespace Ui
{
class SpellCheckDialog;
}

class QUPZILLA_EXPORT SpellCheckDialog : public QDialog
{
    Q_OBJECT

public:
    explicit SpellCheckDialog(QWidget* parent = 0);
    ~SpellCheckDialog();

private slots:
    void changeDictionaryPath();
    void addUserWord();
    void removeUserWord();

    void saveSettings();

private:
    Ui::SpellCheckDialog* ui;

    bool m_listChanged;
};

#endif // SPELLCHECKDIALOG_H
